This crate contains kube-rs compatible bindings for Kubernetes custom resources for the operations.kubeedge.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
operations.kubeedge.io/v1alpha1
ImagePrePullJobNodeUpgradeJob
operations.kubeedge.io/v1alpha2
ConfigUpdateJobImagePrePullJobNodeUpgradeJob